@@ -19,7 +19,23 @@ AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY
 TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """
 
-CATCHUP_FILTER_SECS = 4
-MODEL_PROPAGATION_SECS = 10
-CATCHUP_NETWORK_SECS = 4
-NDEX_DELAY_SECS = 10
+# print(f'Starting {__name__} module')
+
+
+CATCHUP_FILTER_SECS = 1
+MODEL_PROPAGATION_SECS = 5
+CATCHUP_NETWORK_SECS = 2
+
+def set_catchup_filter_secs(delay_secs):
+    global CATCHUP_FILTER_SECS
+    CATCHUP_FILTER_SECS = delay_secs
+
+def set_model_propagation_secs(delay_secs):
+    global MODEL_PROPAGATION_SECS
+    MODEL_PROPAGATION_SECS = delay_secs
+
+def set_catchup_network_secs(delay_secs):
+    global CATCHUP_NETWORK_SECS
+    CATCHUP_NETWORK_SECS = delay_secs
+
+
